@@ -1,6 +1,6 @@
 #!/bin/sh
 
-mkdir -p build && cd build
+mkdir build && cd build
 
 cmake \
   -DCMAKE_PREFIX_PATH=${PREFIX} \
